# Telephone Contacts By Number
A list of telephone contacts saved in the database.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Number:
The telephone number.

### Type:
The telephone's type. Can be one of four types: Fix, Cell, Fax or Other. Fix will be selected by default.

### Entry:
The entry to which the telphone number is assigned.

## Search Field:
Typing in the search field allows to filter the telephone contacts by their number and by the name of the entry they are assigned to.

## Buttons:
Each row can be right-clicked to reveal more options.

### List Of Activities:
Displays a list of activities for the entry of the chosen row.

### Create New Call Activity:
Creates a new call activity for the row's entry.
